/**
 * @file libkydevicesec_phone.h
 * @author chengxiaocui (chengxiaocui@kylinos.cn)
 * @brief 手机管控
 * @version 0.1
 * @date 2024-06-04
 * 
 * @copyright Copyright (c) 2024
 * @defgroup 设备安全
 * @{
 */
#ifndef LIBKYDEVICESEC_PHONE_H
#define LIBKYDEVICESEC_PHONE_H

#ifdef __cplusplus
extern "C" {
#endif

typedef enum _kdk_phone_status {
    KDK_PHONE_DISABLE = 0,
    KDK_PHONE_ENABLE,
    KDK_PHONE_RO,
} kdk_phone_status;

typedef enum _kdk_phone_mode {
    KDK_PHONE_MODE_NORMAL = 0,
    KDK_PHONE_MODE_BLACKLIST,
    KDK_PHONE_MODE_WHITELIST,
} kdk_phone_mode;

struct kdk_phone_dev {
    unsigned char pid[5];
    unsigned char vid[5];
    unsigned char serial[129];
};

/**
 * @brief 设置手机管控状态
 * 
 * @param status 管控状态，参见kdk_phone_status
 * @return int 返回0表示成功，返回其他表示失败（-5000表示门禁管控禁止访问）
 */
extern int kdk_device_set_phone_status(int status);

/**
 * @brief 获取手机管控状态
 * 
 * @return int 返回kdk_phone_status, 返回其他表示失败（-5000表示门禁管控禁止访问）
 */
extern int kdk_device_get_phone_status();

/**
 * @brief 设置手机管控黑白名单模式
 * 
 * @param mode 手机管控模式，参见kdk_phone_mode
 * @return int 返回0表示成功，返回其他表示失败（-5000表示门禁管控禁止访问）
 */
extern int kdk_device_set_phone_bwm(int mode);

/**
 * @brief 获取手机管控黑白名单模式
 * 
 * @return int 返回kdk_phone_mode, 返回其他表示失败（-5000表示门禁管控禁止访问）
 */
extern int kdk_device_get_phone_bwm();

/**
 * @brief 获取手机管控黑名单
 * 
 * @param len 黑名单长度
 * @return struct kdk_phone_dev* 黑名单列表
 */
struct kdk_phone_dev* kdk_device_get_phone_blacklist(int *len);

/**
 * @brief 设置手机管控黑名单
 * 
 * @param dev 手机设备信息结构体
 * @return int 返回0表示成功，返回其他表示失败（-5000表示门禁管控禁止访问）
 */
extern int kdk_device_set_phone_blacklist(struct kdk_phone_dev *dev);

/**
 * @brief 删除手机管控黑名单
 * 
 * @param dev 手机设备信息结构体
 * @return int 返回0表示成功，返回其他表示失败（-5000表示门禁管控禁止访问）
 */
extern int kdk_device_del_phone_blacklist(struct kdk_phone_dev *dev);

/**
 * @brief 清空手机管控黑名单
 * 
 * @return int 返回0表示成功，返回其他表示失败（-5000表示门禁管控禁止访问）
 */
extern int kdk_device_clear_phone_blacklist();

/**
 * @brief 获取手机管控白名单
 * 
 * @param len 黑名单长度
 * @return struct kdk_phone_dev* 黑名单列表
 */
struct kdk_phone_dev* kdk_device_get_phone_whitelist(int *len);

/**
 * @brief 设置手机管控白名单
 * 
 * @param dev 手机设备信息结构体
 * @return int 返回0表示成功，返回其他表示失败（-5000表示门禁管控禁止访问）
 */
extern int kdk_device_set_phone_whitelist(struct kdk_phone_dev *dev);

/**
 * @brief 删除手机管控白名单
 * 
 * @param dev 手机设备信息结构体
 * @return int 返回0表示成功，返回其他表示失败（-5000表示门禁管控禁止访问）
 */
extern int kdk_device_del_phone_whitelist(struct kdk_phone_dev *dev);

/**
 * @brief 清空手机管控白名单
 * 
 * @return int 返回0表示成功，返回其他表示失败（-5000表示门禁管控禁止访问）
 */
extern int kdk_device_clear_phone_whitelist();

#ifdef __cplusplus
}
#endif

#endif